@@ -9,7 +9,7 @@ use vars qw/$VERSION @ISA @EXPORT @EXPORT_OK $ERROR/;
 @EXPORT    = qw//;
 @EXPORT_OK = qw/check_digit is_valid/;
 
-$VERSION = '1.000';
+$VERSION = '1.001.002';
 
 =pod
 
@@ -32,16 +32,6 @@ digit.
 You can find information about the algorithm by searching the web for
 "Damm ECC".  In particular, see the L<SEE ALSO> section (below).
 
-=head1 HISTORY
-
-This module came about as I was reverse engineering a checksum method
-being used on another project of mine.  History of the method used was
-lost to the sands of time, and I needed something to run some quick
-tests on various checksum algorithms.
-
-This module is a reimplementation of one of the algorithms I had
-tested.
-
 =head1 FUNCTIONS
 
 =over 4
@@ -121,14 +111,35 @@ return undef if it is not able to calculate the checksum.
 
 __END__
 
+=head1 HISTORY
+
+This module came about as I was reverse engineering a checksum method
+being used on another project of mine.  History of the method used was
+lost to the sands of time, and I needed something to run some quick
+tests on various checksum algorithms.
+
+This module is a reimplementation of one of the algorithms I had
+tested.
+
 =head1 SEE ALSO
 
 =over 4
 
+=item Algorithm::CheckDigits
+
+L<Algorithm::CheckDigits> is a module that this probably should have
+been written as a part of.  There is an open issue
+(L<https://github.com/MidLifeXis/perl-algorithm-damm/issues/1>) to add
+an integration layer for this module to L<Algorithm::CheckDigits>.
+
 =item Algorithm::LUHN
 
 Original code based on L<Algorithm::LUHN> by Tim Ayers.
 
+=item Math::CheckDigits
+
+Slightly different approach to generating check digits.
+
 =item Wikipedia
 
 L<http://en.wikipedia.org/wiki/Damm_algorithm> - Article explaining
